

class ReolinkError(Exception):
    pass


class InvalidContentTypeError(ReolinkError):
    """Raised when Snapshot command returns an invalid JPEG file"""
    pass


class SnapshotIsNotValidFileTypeError(ReolinkError):
    """Raised when Snapshot command returns an invalid JPEG file"""
    pass


class CredentialsInvalidError(ReolinkError):
    """Raised when an API call returns a credential issue"""
    pass



import re

version_regex = re.compile(r"^v(?P<major>[0-9]+)\.(?P<middle>[0-9]+)\.(?P<minor>[0-9]+).(?P<build>[0-9]+)_([0-9]+)")


class SoftwareVersion:

    """
    :type version_string: str
    """

    def __init__(self, version_string: str):
        self.version_string = version_string

        self.is_unknown = False
        self.major = 0
        self.middle = 0
        self.minor = 0
        self.build = 0

        if version_string.lower() == 'unknown':
            self.is_unknown = True
            return

        match = version_regex.match(version_string)

        if match is None:
            raise Exception("version_string has invalid version format: {}".format(version_string))

        self.major = int(match.group("major"))
        self.middle = int(match.group("middle"))
        self.minor = int(match.group("minor"))
        build = match.group("build")
        if build is None:
            self.build = 0
        else:
            self.build = int(match.group("build"))

    def is_greater_than(self, target_version: 'SoftwareVersion'):
        if self.major > target_version.major:
            return True
        if target_version.major == self.major:
            if self.middle > target_version.middle:
                return True
            if target_version.middle == self.middle:
                if self.minor > target_version.minor:
                    return True
                if target_version.minor == self.minor:
                    if self.build > target_version.build:
                        return True

        return False

    def is_greater_or_equal_than(self, target_version: 'SoftwareVersion'):
        if self.major > target_version.major:
            return True
        if target_version.major == self.major:
            if self.middle > target_version.middle:
                return True
            if target_version.middle == self.middle:
                if self.minor > target_version.minor:
                    return True
                if target_version.minor == self.minor:
                    if self.build >= target_version.build:
                        return True

        return False

    def is_lower_than(self, target_version: 'SoftwareVersion'):
        if self.major < target_version.major:
            return True
        if target_version.major == self.major:
            if self.middle < target_version.middle:
                return True
            if target_version.middle == self.middle:
                if self.minor < target_version.minor:
                    return True
                if target_version.minor == self.minor:
                    if self.build < target_version.build:
                        return True
        return False

    def is_lower_or_equal_than(self, target_version: 'SoftwareVersion'):
        if self.major < target_version.major:
            return True
        if target_version.major == self.major:
            if self.middle < target_version.middle:
                return True
            if target_version.middle == self.middle:
                if self.minor < target_version.minor:
                    return True
                if target_version.minor == self.minor:
                    if self.build <= target_version.build:
                        return True
        return False

    def equals(self, target_version: 'SoftwareVersion'):
        if target_version.major == self.major and target_version.middle == self.middle and \
                target_version.minor == self.minor and target_version.build == self.build:
            return True
        return False

    def __lt__(self, other):
        return self.is_lower_than(other)

    def __le__(self, other):
        return self.is_lower_or_equal_than(other)

    def __gt__(self, other):
        return self.is_greater_than(other)

    def __ge__(self, other):
        return self.is_greater_or_equal_than(other)

    def __eq__(self, target_version):
        if target_version.major == self.major and target_version.middle == self.middle and \
                target_version.minor == self.minor and target_version.build == self.build:
            return True
        return False

    def generate_str_from_numbers(self):
        return "{}.{}.{}-{}".format(self.major, self.middle, self.minor, self.build)


from distutils.core import setup

setup(
    name='reolink',
    packages=['reolink'],
    version='0.0.59',
    license='MIT',
    description='Reolink camera package',
    author='fwestenberg',
    author_email='',
    url='https://github.com/fwestenberg/reolink',
    download_url='https://github.com/fwestenberg/reolink/releases/latest',
    keywords=['Reolink', 'Home-Assistant'],
    install_requires=[
        'ffmpeg',
        'requests',
        'aiohttp'
    ],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9'
    ],
)
